.. module:: enaml.widgets.status_bar

========================
enaml.widgets.status_bar
========================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    StatusBar


.. autoclass:: StatusBar
